[prev in list] [next in list] [prev in thread] [next in thread] 

List:       kde-usability
Subject:    Fwd: Re: [kde] creating a link to a directory
From:       Martin Koller <m.koller () surfeu ! at>
Date:       2004-12-24 14:17:44
Message-ID: 200412241517.44215.m.koller () surfeu ! at
[Download RAW message or body]

Hi all,

I found the following question on the kde list, and reading the answer, I ask 
myself if it is understandable by a newbie to find the "Link to Location ..." 
below the "File" menu.

(Also, as I do not create a Device itself, it should be called "Link to 
device")

I propose to move the entries "Link to Application" and "Link to Location" one 
level up, so that I have create new->
* Folder ...
* Link To Application ...
* Link to Location ...
* File >>  
* Link To Device >>

Do you think the attached patch is OK ?

----------  Forwarded Message  ----------

Subject: Re: [kde] creating a link to a directory
Date: Monday 20 December 2004 11:42
From: icebox <icebox@miv.directnet.ro>
To: kde@mail.kde.org, jsowden@americansentry.net

On Monday 20 December 2004 08:32, John Sowden wrote about [kde] creating

a link to a directory:
> I am trying to create a link to a directory where I have some
> programs to run. I don't want to start the browser (url), just open a
> window to a directory, but not the desktop.  How do I associat an
> icon on the desktop to, say,: /home/john/accounting
>
> thanks,
>
>(...)

Right click on the desktop,
Go to:
Create New -> File -> Link to location.


-- 
Best regards/Schöne Grüße

Martin    ()  ascii ribbon campaign - against html mail 
          /\                        - against microsoft attachments

       Some operating systems are called 'user friendly',
             Linux however is 'expert friendly'.

["newmenu.patch" (text/x-diff)]

Index: knewmenu.cc
===================================================================
RCS file: /home/kde/kdebase/libkonq/knewmenu.cc,v
retrieving revision 1.99
diff -u -3 -p -r1.99 knewmenu.cc
--- knewmenu.cc	6 Nov 2004 17:04:51 -0000	1.99
+++ knewmenu.cc	24 Dec 2004 14:14:26 -0000
@@ -93,7 +93,7 @@ KNewMenu::~KNewMenu()
 
 void KNewMenu::makeMenus()
 {
-    d->m_menuDev = new KActionMenu( i18n( "Device" ), "kcmdevices", d->m_actionCollection, "devnew" );
+    d->m_menuDev = new KActionMenu( i18n( "Link to Device" ), "kcmdevices", d->m_actionCollection, \
                "devnew" );
     d->m_menuNew = new KActionMenu( i18n( "File" ), "filenew", d->m_actionCollection, "devnew" );
 }
 
@@ -235,8 +235,10 @@ void KNewMenu::fillMenu()
             {
                 Entry entry = *(s_templatesList->at( i-1 ));
 
-                    // The best way to identify the "Create Directory" was the template
-                if((*templ).templatePath.right( 8 ) == "emptydir")
+                // The best way to identify the "Create Directory", "Link to Location", "Link to \
Application" was the template +                if ( ((*templ).templatePath.endsWith( "emptydir" )) ||
+                     ((*templ).templatePath.endsWith( "URL.desktop" )) ||
+                     ((*templ).templatePath.endsWith( "Program.desktop" )) )
                 {
                     KAction * act = new KAction( (*templ).text, (*templ).icon, 0, this, SLOT( \
                slotNewDir() ),
                                      d->m_actionCollection, QCString().sprintf("newmenu%d", i ) );
@@ -319,7 +321,9 @@ void KNewMenu::slotFillTemplates()
             e.filePath = *it;
             e.entryType = 0; // not parsed yet
             // put Directory first in the list (a bit hacky)
-            if ( (*it).endsWith( "Directory.desktop" ) )
+            if ( (*it).endsWith( "Directory.desktop" ) ||
+                 (*it).endsWith( "linkProgram.desktop" ) ||
+                 (*it).endsWith( "linkURL.desktop" ) )
                 s_templatesList->prepend( e );
             else
             {



_______________________________________________
kde-usability mailing list
kde-usability@kde.org
https://mail.kde.org/mailman/listinfo/kde-usability


[prev in list] [next in list] [prev in thread] [next in thread] 

Configure | About | News | Add a list | Sponsored by KoreLogic